package X3D::FieldTypes::MFColor;

our $VERSION = '0.009';

use X3D::Package 'MFColor : X3DArrayField { [] }';

1;
__END__
